CBService class final
- Inheritance
-
- Object
- CBAttribute
- CBService
- Implementers
Constructors
-
CBService({required String handle, required CBPeripheral? peripheral, required CBUUID uuid, required bool isPrimary, required List<
CBService> ? includedServices, required List<CBCharacteristic> ? characteristics}) -
CBService.fromMap({required CBPeripheral peripheral, required Map<
Object?, Object?> map}) -
factory
Properties
-
characteristics
→ List<
CBCharacteristic> ? -
no setter
- handle ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includedServices
→ List<
CBService> ? -
no setter
- isPrimary → bool
-
no setter
- peripheral → CBPeripheral?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → CBUUID
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCharacteristics(
List< CBCharacteristic> ? characteristics) → void -
updateIncludedServices(
List< CBService> ? includedServices) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited