CBMutableDescriptor class final
- Inheritance
-
- Object
- CBAttribute
- CBDescriptor
- CBMutableDescriptor
Constructors
- CBMutableDescriptor({required String handle, required CBCharacteristic? characteristic, required CBUUID uuid, required Object? value, String? clientReference})
-
CBMutableDescriptor.fromMap(Map<
Object?, Object?> map) -
factory
- CBMutableDescriptor.type({required CBUUID type, Object? value, CBCharacteristic? characteristic, String handle = '', String? clientReference})
Properties
- characteristic → CBCharacteristic?
-
no setterinherited
- handle ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → CBUUID
-
finalinherited
- value ↔ Object?
-
getter/setter pairinherited-getter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
updateValue(
Object? value) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited